@@ -6,7 +6,7 @@ class Config(object):
     ''' Base config class to easily pass headers, etc.
     '''
     config = EasyConfig('djpubsubhubbub.Config', 'PUBSUBHUBBUB_CONFIG')
-    
+
     def get_extra_hub_headers(self, feed_url, hub_url):
         return self.config.get_object(
             'get_extra_hub_headers',
@@ -20,3 +20,10 @@ class Config(object):
             str(Site.objects.get_current()),
             *(feed_url, hub_url)
         )
+
+    def get_default_callback_scheme(self, feed_url, hub_url):
+        return self.config.get_object(
+            'get_default_callback_scheme',
+            'http',
+            *(feed_url, hub_url)
+        )
